import { formatDate, paddingZero } from './utils.js'
import { ref } from 'vue'
import constants from './constants.js'
import $i from './i18n.js'
class Bus {
	constructor(){
		this.listeners = {}
		this.statusLog = ref([])
		this.report(constants.MAGIC_API_VERSION);
	}
	$on(name, callback){
		this.listeners[name] = this.listeners[name] || [];
		this.listeners[name].push(callback)
	}
	$event(name, callback){
		this.$on(`ws_${name}`, callback)
	}
	$emit(name) {
		const functions = this.listeners[name]
		if(functions){
			const params = []
			for(var i=1,len=arguments.length;i<len;i++){
				params.push(arguments[i]);
			}
			functions.forEach(fn => fn.apply(this, params))
		}
	}
	report(eventId){
		try {
			fetch('https://console.ssssssss.org.cn/event?e=' + eventId)
		} catch (ignored) {
	
		}
	}
	send(msgType, content){
		this.$emit('message', msgType, content)
	}
	status(content, flag, ...args){
		const date = new Date()
		content = $i(content, ...args) || content
		if(flag === false){
			content = `<font color="red">${content}</font>`
		}
		this.statusLog.value.push({
			content,
			timestamp : formatDate(date) + "." + paddingZero(date.getMilliseconds(), 3)
		})
		this.$emit('status', content)
	}
	clearStatusLog(){
		this.statusLog.value = []
	}
	getStatusLog(){
		return this.statusLog
	}
}

export default new Bus()